Learn R Programming

semidist (version 0.1.0)

mv_sis: Feature screening via MV Index

Description

Implement the feature screening for the classification problem via MV index.

Usage

mv_sis(X, y, d = NULL, parallel = FALSE)

Value

A list of the objects about the implemented feature screening:

  • measurement: sample MV index calculated for each single covariate;

  • selected: indicies or names (if avaiable as colnames of X) of covariates that are selected after feature screening;

  • ordering: order of the calculated measurements of each single covariate. The first one is the largest, and the last is the smallest.

Arguments

X

Data of multivariate covariates, which should be an \(n\)-by-\(p\) matrix.

y

Data of categorical response, which should be a factor of length \(n\).

d

An integer specifying how many features should be kept after screening. Defaults to NULL. If NULL, then it will be set as \([n / log(n)]\), where \([x]\) denotes the integer part of x.

parallel

A boolean indicating whether to calculate parallelly via furrr::future_map. Defaults to FALSE.

Examples

Run this code
X <- mtcars[, c("mpg", "disp", "hp", "drat", "wt", "qsec")]
y <- factor(mtcars[, "am"])

mv_sis(X, y, d = 4)

Run the code above in your browser using DataLab